#
# spec file for package pam_mktemp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pam_mktemp
URL:            http://www.openwall.com/pam/
BuildRequires:  e2fsprogs-devel
BuildRequires:  pam-devel
Requires:       pam
Provides:       pam-modules:%{_pam_moduledir}/pam_mktemp.so
Version:        1.1.1
Release:        11.5
Summary:        PAM Module to Provide Per-User Private Directories Under /tmp
License:        SUSE-Permissive
Group:          System/Libraries
Source0:        %{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source50:       dlopen.sh
Patch0:         pam_mktemp-1.1.1-Makefile.patch
Patch1:         pam_mktemp-1.1.1-ppc64.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PAM (Pluggable Authentication Modules) is a system security tool that
allows system administrators to set authentication policies without
having to recompile programs that do authentication.

pam_mktemp is a PAM module which may be used with a PAM-aware login
service to provide per-user private directories under /tmp as a part of
PAM session or account management.

%prep
%autosetup -p1

%build
EXTRA_CFLAGS="-fno-strict-aliasing"
%ifnarch ia64
    EXTRA_CFLAGS="$EXTRA_CFLAGS -Wa,--noexecstack"
%endif
make CFLAGS="$RPM_OPT_FLAGS $EXTRA_CFLAGS -fPIC -DHAVE_SHADOW -DLINUX_PAM" \
	%{?_smp_mflags}

%install
make DESTDIR=%{buildroot} SHARED_LIBDIR=/"%{_lib}" DEVEL_LIBDIR="%{_libdir}" SECUREDIR="%{_pam_moduledir}" install
# Remove stuff we don't wish to have now. Note that "make" seems to install library files in /usr/lib!
rm -rf %{buildroot}%{_prefix}/include/security/*.h %{buildroot}/usr/lib/lib*

%check
# Check for module problems.  Specifically, check that every module we just
# installed can actually be loaded by a minimal PAM-aware application.
export LD_LIBRARY_PATH="%{buildroot}/%{_lib}/"
for module in %{buildroot}%{_pam_moduledir}/pam*.so ; do
   if ! sh $RPM_SOURCE_DIR/dlopen.sh -lpam -ldl ${module} ; then
      exit 1
   fi
done

%files 
%defattr(-,root,root,755)
%doc LICENSE README
%attr(755,root,root) %{_pam_moduledir}/pam_*.so

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Oct 27 2021 Josef Möllers <josef.moellers@suse.com>
- Split the install section into an install and a check section.
  Otherwise i[345]86 will not build.
* Mon Oct  4 2021 Josef Möllers <josef.moellers@suse.com>
- Use the %%_pam_moduledir macro in pam_mktemp.spec in order to
  have the package follow UsrMerge.
  [bsc#1190953, pam_mktemp.spec]
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Dec  7 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Wed Dec  7 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Wed Oct 13 2010 tabraham@novell.com
- update to version 1.1.1 from 1.0.3
  * Documented the USE_SELINUX and USE_APPEND_FL compile-time
    settings
  * Updated the authorship, copyright, and licensing statements
    to use the cut-down BSD license only (no public domain with
    a license fallback anymore, which would be too cumbersome
    with significant contributions by two authors
  * Use ext2fs/ext2_fs.h instead of linux/ext2_fs.h to avoid
    potential build problems with fresh kernel headers
  * Clear append-only flag from user directory iff the directory
    was actually created
  * Replaced unsafe alloca(3) with malloc(3)
  * Imported SELinux support from Sisyphus
  * In SELinux support, save and restore file creation context
  * No longer set the append-only flag on /tmp/.private
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jun 24 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 mc@suse.de
- update to version 1.0.3
  - Restricted list of global symbols exported by the PAM module
    to standard set of six pam_sm_* functions.
  - Changed Makefile to pass list of libraries to linker after regular
    object files, to fix build with -Wl,--as-needed.
  - Corrected specfile to make it build on x86_64.
* Thu Mar 22 2007 ssommer@suse.de
- fix build with newer kernel headers
* Wed Aug  9 2006 mc@suse.de
- version 1.0.2 branched from pam-modules
